#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 blaze-html
version:              0.9.2.0
visibility:           public
id:                   blaze-html-0.9.2.0-GzsXlvfrcqyCxImJscSKAz
key:                  blaze-html-0.9.2.0-GzsXlvfrcqyCxImJscSKAz
license:              BSD-3-Clause
maintainer:           Jasper Van der Jeugt <m@jaspervdj.be>
author:               Jasper Van der Jeugt, Simon Meier
stability:            Experimental
homepage:             http://jaspervdj.be/blaze
synopsis:             A blazingly fast HTML combinator library for Haskell
description:
    A blazingly fast HTML combinator library for the Haskell
    programming language. The Text.Blaze module is a good
    starting point, as well as this tutorial:
    <http://jaspervdj.be/blaze/tutorial.html>.

category:             Text
abi:                  75e844f8c45a6b4003a1aaad0a80c4a3
exposed:              True
exposed-modules:
    Text.Blaze.Html Text.Blaze.Html.Renderer.Pretty
    Text.Blaze.Html.Renderer.String Text.Blaze.Html.Renderer.Text
    Text.Blaze.Html.Renderer.Utf8 Text.Blaze.Html4.FrameSet
    Text.Blaze.Html4.FrameSet.Attributes Text.Blaze.Html4.Strict
    Text.Blaze.Html4.Strict.Attributes Text.Blaze.Html4.Transitional
    Text.Blaze.Html4.Transitional.Attributes Text.Blaze.Html5
    Text.Blaze.Html5.Attributes Text.Blaze.XHtml1.FrameSet
    Text.Blaze.XHtml1.FrameSet.Attributes Text.Blaze.XHtml1.Strict
    Text.Blaze.XHtml1.Strict.Attributes Text.Blaze.XHtml1.Transitional
    Text.Blaze.XHtml1.Transitional.Attributes Text.Blaze.XHtml5
    Text.Blaze.XHtml5.Attributes

import-dirs:          /usr/lib/ghc-9.6.6/site-local/blaze-html-0.9.2.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/blaze-html-0.9.2.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/blaze-html-0.9.2.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-blaze-html
hs-libraries:         HSblaze-html-0.9.2.0-GzsXlvfrcqyCxImJscSKAz
depends:
    base-4.18.2.1 blaze-builder-0.4.4.1-6b9visw8HKrC1WJWquHe2m
    blaze-markup-0.8.3.0-BOWeQpAnxz8Cf8hQ9GVt6j bytestring-0.11.5.3
    text-2.0.2

haddock-interfaces:   /usr/share/doc/haskell-blaze-html/html/blaze-html.haddock
haddock-html:         /usr/share/doc/haskell-blaze-html/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

